@@ -8,7 +8,6 @@ use std::fmt;
 use std::io;
 use std::str;
 
-use anyhow::Context;
 use console::{Style, Term};
 use dialoguer::{theme, Confirm, Input, MultiSelect, Select};
 use futures::StreamExt;
@@ -1047,11 +1046,11 @@ impl StateHub {
         let kubectls = k8s::Kubectl::with_names_and_contexts(names, contexts)?;
 
         for kubectl in kubectls {
-            self.inform2(format_args!(
+            self.inform(format_args!(
                 "Updating cluster with K8s context {} with {:?}",
                 kubectl.cluster_name(),
                 azure
-            ))?;
+            ));
             let azure = Some(&azure);
             let aws = Some(&aws);
             self.setup_credentials_helper(&kubectl, &namespace, aws, azure)
@@ -1071,18 +1070,18 @@ impl StateHub {
 
     async fn diagnose_cluster(&self, kubectls: Vec<k8s::Kubectl>) -> anyhow::Result<()> {
         for kubectl in kubectls {
-            self.inform2(format_args!(
+            self.inform(format_args!(
                 "Running diagnostics on cluster '{}' (K8s context '{}')",
                 kubectl.cluster_name(),
                 kubectl.context(),
-            ))?;
+            ));
             let check_cluster = kubectl.check_cluster();
             futures::pin_mut!(check_cluster);
             while let Some(item) = check_cluster.next().await {
                 match item {
-                    Ok(text) => self.inform2(text)?,
+                    Ok(text) => self.inform(text),
                     Err(text) => {
-                        self.inform2(text)?;
+                        self.inform(text);
                         break;
                     }
                 }
@@ -1099,8 +1098,8 @@ impl StateHub {
         non_interactive: bool,
     ) -> anyhow::Result<()> {
         if force || non_interactive || self.confirm_with_default("Are you sure?", false) {
-            log::info!("Make sure all the pods using statehub are terminated");
-            log::info!("Uninstall helm");
+            self.inform("Make sure all the pods using statehub are terminated");
+            self.inform("And then manually run 'helm uninstall'");
             for kubectl in kubectls {
                 self.unregister_cluster_helper(kubectl, helm).await?;
             }
@@ -1118,11 +1117,11 @@ impl StateHub {
             AddLocation::FromLocation(location) => vec![location],
             AddLocation::FromCluster(cluster) => {
                 let locations = self.api.get_cluster(&cluster).await?.all_locations();
-                self.inform2(format_args!(
+                self.inform(format_args!(
                     "Cluster {} available in {}",
                     cluster,
                     locations.iter().map(ToString::to_string).join(" and ")
-                ))?;
+                ));
                 locations
             }
         };
@@ -1132,12 +1131,12 @@ impl StateHub {
         for location in locations {
             let state = self.api.get_state(&state).await?;
             if state.is_available_in(&location) {
-                self.inform2(format_args!(
+                self.inform(format_args!(
                     "State {} is already available in {:#}",
                     state, location
-                ))?;
+                ));
             } else {
-                self.inform2(format_args!("Extending state {} to {:#}", state, location))?;
+                self.inform(format_args!("Extending state {} to {:#}", state, location));
                 self.add_location_helper(&state, &location, wait).await?;
             }
         }
@@ -1399,23 +1398,19 @@ impl StateHub {
     }
 
     async fn save_config(&self, set_default_profile: bool) -> anyhow::Result<()> {
-        self.config.save(set_default_profile).and_then(|path| {
-            self.inform2(format_args!("Saving config to {}", path.display()))
-                .context("Inform")
-        })
+        self.config
+            .save(set_default_profile)
+            .map(|path| self.inform(format_args!("Saving config to {}", path.display())))
     }
 
     async fn check_for_update(&self) {
         if !self.json && Config::more_than_one_day_passed_since_last_check() {
-            self.check_for_update_helper()
-                .await
-                .and_then(|(current, latest)| {
-                    self.inform2(format_args!(
-                        "\nNewer version '{}' is available (you have '{}')\n",
-                        latest, current
-                    ))
-                    .ok()
-                });
+            if let Some((current, latest)) = self.check_for_update_helper().await {
+                self.inform(format_args!(
+                    "\nNewer version '{}' is available (you have '{}')\n",
+                    latest, current
+                ))
+            }
             Config::touch_update();
         }
     }
@@ -1453,16 +1448,10 @@ impl StateHub {
     }
 
     fn inform(&self, text: impl fmt::Display) {
-        self.inform2(text).ok();
-    }
-
-    fn inform2(&self, text: impl fmt::Display) -> io::Result<()> {
         let text = format!("{}", self.style.apply_to(text));
-        // let text = text.to_string();
         if !text.is_empty() {
-            self.stdout.write_line(&text)?;
+            self.stdout.write_line(&text).ok();
         }
-        Ok(())
     }
 
     fn error(&self, text: impl fmt::Display) -> io::Result<()> {
@@ -1510,17 +1499,27 @@ impl StateHub {
             .map(|idx| items[idx].clone())
     }
 
-    fn multiselect_with_default<P, T>(&self, prompt: P, items: &[T]) -> io::Result<Vec<T>>
+    fn multiselect_with_default<P, T>(
+        &self,
+        prompt: P,
+        items: &[T],
+        default: usize,
+    ) -> io::Result<Vec<T>>
     where
         P: Into<String>,
         T: Clone + ToString,
     {
+        let items = items
+            .iter()
+            .enumerate()
+            .map(|(idx, item)| (item.clone(), idx == default))
+            .collect::<Vec<_>>();
         let items = MultiSelect::with_theme(self.theme())
             .with_prompt(prompt)
-            .items(items)
+            .items_checked(&items)
             .interact_on(&self.stdout)?
             .into_iter()
-            .map(|idx| items[idx].clone())
+            .map(|idx| items[idx].0.clone())
             .collect();
 
         Ok(items)
