@@ -149,8 +149,17 @@ impl StateHub {
         } else if states.is_empty() {
             Some(states)
         } else {
-            self.multiselect_with_default("Select states to use with this cluster", &all_states)
-                .ok()
+            let default = all_states
+                .iter()
+                .position(|item| item.0 == "default")
+                .unwrap_or_default();
+
+            self.multiselect_with_default(
+                "Select states to use with this cluster",
+                &all_states,
+                default,
+            )
+            .ok()
         };
 
         let claim_unowned_states = !no_state_owner
@@ -259,12 +268,12 @@ impl StateHub {
             .await
             .map(Quiet)?;
 
-        self.inform2(format_args!(
+        self.inform(format_args!(
             "Registering {:#} cluster {} in {}",
             provider,
             cluster.name,
             locations.show(),
-        ))?;
+        ));
 
         let event = self.install_statehub_cluster_event(namespace);
         let event = kubectl
@@ -353,9 +362,16 @@ impl StateHub {
     }
 
     fn azure_credentials_helper(&self, azure: AzureCredentials) -> AzureCredentials {
+        let azcli_installed = which::which("az").is_ok();
         if azure.missing() {
             self.inform("Azure/AKS cluster detected and you didn't provide any Azure credentials");
-            self.inform("Please follow this link to create Azure credentials: https://statehub.io/creds/azure");
+            if azcli_installed {
+                self.inform("Since you seem to have AZ CLI installed please run following command");
+            } else {
+                self.inform("Please follow this link to open Azure Cloud Shell: https://shell.azure.com/bash");
+                self.inform("and run following command there");
+            }
+            self.inform("wget https://get.statehub.io/create_statehub_service_principal.sh && bash create_statehub_service_principal.sh");
             self.inform("When done please copy/paste credentials here");
             let tenant_id = self.input("AZURE_TENANT_ID").unwrap_or_default();
             let client_id = self.input("AZURE_CLIENT_ID").unwrap_or_default();
@@ -530,10 +546,10 @@ or run following commands before running 'statehub register-cluster`
                     location
                 );
             } else {
-                self.inform2(format_args!(
+                self.inform(format_args!(
                     "Extending state {} to {}",
                     state.name, location
-                ))?;
+                ));
                 self.add_location_helper(state, location, wait).await?;
             }
         }
@@ -731,7 +747,7 @@ or run following commands before running 'statehub register-cluster`
 
     pub(super) async fn update_helper(&self, version: semver::Version) -> anyhow::Result<()> {
         let version = version.to_string();
-        self.inform2(format_args!("Downloading version {}", version))?;
+        self.inform(format_args!("Downloading version {}", version));
         let file = self
             .get_package("statehub", &version)
             .await
