@@ -121,7 +121,7 @@ impl Show for Cluster {
     }
 
     fn detailed_show(&self) -> String {
-        let helm = k8s::Helm::new(true);
+        let helm = k8s::Helm::skip();
         let namespace = self.namespace.as_deref().unwrap_or("statehub-system");
         let helm = helm.install_command(self, None, namespace);
         format!(
